@@ -6,9 +6,6 @@
 #' side(s).
 #'
 #' @inheritParams str_after_nth
-#' @param pattern A string. The pattern to be trimmed (*not* interpreted as
-#'   regular expression). So to trim a period, use `char = "."` and not
-#'   `char = "\\\\."`).
 #' @param side Which side do you want to trim from? `"both"` is the
 #'   default, but you can also have just either `"left"` or `"right"`
 #'   (or optionally the shortened `"b"`, `"l"` and `"r"`).
@@ -16,19 +13,29 @@
 #' @return A string.
 #' @examples
 #' str_trim_anything("..abcd.", ".", "left")
+#' str_trim_anything("..abcd.", coll("."), "left")
 #' str_trim_anything("-ghi--", "-")
 #' str_trim_anything("-ghi--", "--")
+#' str_trim_anything("-ghi--", "i-+")
 #' @family removers
 #' @export
 str_trim_anything <- function(string, pattern, side = "both") {
   if (is_l0_char(string)) {
     return(character())
   }
+  if (all(c("boundary", "pattern") %in% class(pattern))) {
+    custom_stop(
+      "`str_trim_anything()` cannot handle a `pattern` of type 'boundary'."
+    )
+  }
   verify_string_pattern(string, pattern)
   checkmate::assert_string(side)
   side %<>% match_arg(c("both", "left", "right"), ignore_case = TRUE)
-  pattern <- ore::ore.escape(pattern) %>%
-    str_c("(?:", ., ")")
+  if (any(c("coll", "fixed") %in% class(pattern)) &&
+      "pattern" %in% class(pattern)) {
+    pattern %<>% ore::ore.escape()
+  }
+  pattern %<>% str_c("(", ., ")")
   switch(side,
     both = str_replace(string, str_c("^", pattern, "*"), "") %>%
       str_replace(str_c(pattern, "*$"), ""),
